@@ -65,7 +65,7 @@ class utility:
 
             response_iterator = paginator.paginate()
             header = ['InstanceId','VolumeID', 'Size(GB)', 'Availability Zone','Volume Type','Status','IOPS']
-            with open('ebs_report_+'region+'.csv','w', newline = '') as csvfile:
+            with open('ebs_report.csv','w', newline = '') as csvfile:
                 writer = csv.writer(csvfile)
                 writer.writerow(header)
                 for page in response_iterator:
